@@ -13,7 +13,7 @@ class Project:
         self.name = str(uuid4()).replace('-', '')
         self.image_name = image_name
         self.client = docker.Client(
-            base_url=os.getenv('DOCKER_1_PORT', 'unix://var/run/docker.sock'),
+            base_url=os.getenv('DOCKER_HOST', 'unix://var/run/docker.sock'),
             version='1.9',
             timeout=10
         )
